# paddle-prompt

Prompt Toolkit for PaddlePaddle Deep Learning Framework. Inspired by [thunlp/OpenPrompt](https://github.com/thunlp/OpenPrompt).

***

## Installation

`paddle-prompt` is built under Python3.7+ and [Paddle](https://github.com/PaddlePaddle/Paddle). You can install `paddle-prompt` with pip:

```shell
pip install paddle-prompt
```

## TODOS

- [ ] complete PLMs
- [ ] complete template
- [ ] complete verbalizer
- [ ] create text classification datasets
- ...



## Stargazers over time

[![Stargazers over time](https://starchart.cc/wj-Mcat/paddle-prompt.svg)](https://github.com/wj-Mcat/paddle-prompt)

## Contributors

<a href="https://github.com/wj-Mcat/paddle-prompt/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=wj-Mcat/paddle-prompt" />
</a>

Made with [contrib.rocks](https://contrib.rocks)

## Creators

- [@wj-Mcat](https://github.com/wj-Mcat) - Jingjing WU (吴京京)

## Copyright & License

- Code & Docs © 2022 wj-MCat <https://github.com/wj-Mcat>
- Code released under the Apache-2.0 License
- Docs released under Creative Commons